Files
~~~~~

Files are the top-level object for any piece of data in a workspace.

A file is always uploaded as raw data and then processed by a Blockifier plugin to convert it into :ref:`Steamship Block format<Data Model>`.
This means a Steamship File has a broader definition than "file on your desktop." It could be a PDF file, a YouTube video, or the JSON representation of an AirTable table or a Notion document.

Actions on Files
^^^^^^^^^^^^^^^^

You can take the following actions on files.

- Upload
- Blockify
- Query
